@@ -1,22 +1,35 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Dist::Zilla::Plugin::Git::NextVersion::Sanitized;
-BEGIN {
-  $Dist::Zilla::Plugin::Git::NextVersion::Sanitized::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Dist::Zilla::Plugin::Git::NextVersion::Sanitized::VERSION = '0.001000';
-}
+
+our $VERSION = '0.002000';
 
 # ABSTRACT: Sanitize versions handed to you by Git::NextVersion
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
-use Moose;
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+use Moose qw( extends with );
 extends 'Dist::Zilla::Plugin::Git::NextVersion';
 with 'Dist::Zilla::Role::Version::Sanitize';
 
-
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
@@ -34,7 +47,7 @@ Dist::Zilla::Plugin::Git::NextVersion::Sanitized - Sanitize versions handed to y
 
 =head1 VERSION
 
-version 0.001000
+version 0.002000
 
 =head1 SYNOPSIS
 
@@ -55,7 +68,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
